@@ -8,7 +8,7 @@ package Object::Pad;
 use strict;
 use warnings;
 
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 
 use Carp;
 
@@ -226,6 +226,57 @@ find any new restrictions to be majorly problematic. Either the code will
 continue to run unaffected, or you may have to make some small alterations to
 bring it into a conforming style.
 
+=head1 STYLE SUGGESTIONS
+
+While in no way required, the following suggestions of code style should be
+noted in order to establish a set of best practices, and encourage consistency
+of code which uses this module.
+
+=head2 File Layout
+
+Begin the file with a C<use Object::Pad> line; ideally including a
+minimum-required version. This should be followed by the toplevel C<class>
+declaration for the file. As it is at toplevel there is no need to use the
+block notation; it can be a unit class.
+
+There is no need to C<use strict> or apply other usual pragmata; these will
+be implied by the C<class> keyword.
+
+   use Object::Pad 0.16;
+
+   class My::Classname 1.23;
+
+   # other use statements
+
+   # has, methods, etc.. can go here
+
+=head2 Slot Names
+
+Slot names should follow similar rules to regular lexical variables in code -
+lowercase, name components separated by underscores. For tiny examples such as
+"dumb record" structures this may be sufficient.
+
+   class Tag {
+      has $name;  method name  :lvalue { $name }
+      has $value; method value :lvalue { $value }
+   }
+
+In larger examples with lots of non-trivial method bodies, it can get
+confusing to remember where the slot variables come from (because we no longer
+have the C<< $self->{ ... } >> visual clue). In these cases it is suggested to
+prefix the slot names with a leading underscore, to make them more visually
+distinct.
+
+   class Spudger {
+      has $_grapefruit;
+
+      ...
+
+      method mangle {
+         $_grapefruit->peel; # The leading underscore reminds us this is a slot
+      }
+   }
+
 =cut
 
 sub import
